==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/PolarSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarSplineAreaSeriesDescription } from "./PolarSplineAreaSeriesDescription";
/**
 * @hidden
 */
export let PolarSplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarSplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarSplineAreaSeriesDescriptionMetadata.a == null) {
                PolarSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarSplineAreaSeriesDescriptionMetadata.c(PolarSplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.j(PolarSplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(PolarSplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("Stiffness", "Number:double");
        }
        static d(a) {
            PolarSplineAreaSeriesDescriptionMetadata.b(a);
            a.aa("PolarSplineAreaSeries", () => new PolarSplineAreaSeriesDescription());
            a.z("PolarSplineAreaSeries", PolarSplineAreaSeriesDescriptionMetadata.a);
        }
    }
    PolarSplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarSplineAreaSeriesDescriptionMetadata, 'PolarSplineAreaSeriesDescriptionMetadata');
    PolarSplineAreaSeriesDescriptionMetadata.a = null;
    return PolarSplineAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PolarSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarSplineAreaSeriesDescription } from "./PolarSplineAreaSeriesDescription";
/**
 * @hidden
 */
export let PolarSplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarSplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarSplineAreaSeriesDescriptionMetadata.a == null) {
                PolarSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarSplineAreaSeriesDescriptionMetadata.c(PolarSplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarSplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(PolarSplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("Stiffness", "Number:double");
        }
        static d(a) {
            PolarSplineAreaSeriesDescriptionMetadata.b(a);
            a.ac("PolarSplineAreaSeries", () => new PolarSplineAreaSeriesDescription());
            a.ab("PolarSplineAreaSeries", PolarSplineAreaSeriesDescriptionMetadata.a);
        }
    }
    PolarSplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarSplineAreaSeriesDescriptionMetadata, 'PolarSplineAreaSeriesDescriptionMetadata');
    PolarSplineAreaSeriesDescriptionMetadata.a = null;
    return PolarSplineAreaSeriesDescriptionMetadata;
})();
